<?php

namespace Bydedi\Avalara\Adapter;

use Bydedi\Avalara\Model\Address;
use Bydedi\Avalara\Model\Customer;
use Bydedi\Avalara\Model\Product;
use Bydedi\Avalara\Model\Shipping;

/**
 * Class CommandeAdapter
 * @package Bydedi\Avalara\Adapter
 */
class CommandeSessionAdapter
{
    /**
     * @var array
     */
    protected $commande;

    /**
     * CommandeAdapter constructor.
     * @param array $commande
     */
    public function __construct(array $commande)
    {
        $this->commande = $commande;
    }

    /**
     * ////////////////////////////////////
     * GETTERS & SETTERS
     * ////////////////////////////////////
     */

    /**
     * @return array
     */
    public function getCommande()
    {
        return $this->commande;
    }

    /**
     * @param $commande
     * @return $this
     */
    public function setCommande(array $commande)
    {
        $this->commande = $commande;
        return $this;
    }

    /**
     * ////////////////////////////////////
     * PUBLIC METHODS
     * ////////////////////////////////////
     */

    /**
     * @return Customer
     */
    public function getCustomer()
    {
        $customer = new Customer();
        $commande = $this->getCommande();
        $customer->code = $commande['client_id'];

        return $customer;
    }

    /**
     * @return Address
     */
    public function getAddressShipping(){
        $commande = $this->getCommande();

        $address = new Address();
        $address
            ->setLine1($commande['livraison_rue'])
            ->setLine2($commande['livraison_rue2'])
            ->setCity($commande['livraison_ville'])
            ->setCountry($commande['livraison_pays_code'])
            ->setPostalCode($commande['livraison_cp']);

        if(!empty($commande['livraison_state_us_code'])){
            $address->setRegion($commande['livraison_state_us_code']);
        }

        return $address;
    }

    /**
     * @return array
     */
    public function getProducts()
    {
        $result = array();
        $commande = $this->getCommande();
        foreach($commande['produits'] as $p){
            $product = new Product();

            $code = 'P0000000';
            if(!empty($p['produit_code_avalara'])) {
                $code = $p['produit_code_avalara'];
            }
            $product
                ->setIdentifier($p['commande_produit_id'])
                ->setPriceHt($p['prix_ht'])
                ->setQuantity((float)$p['produit_quantite'])
                ->setTaxCode($code);
            $result[] = $product;
        }
        return $result;
    }

    /**
     * @return Shipping
     */
    public function getShipping(){
        $commande = $this->getCommande();
        $shipping = new Shipping();
        $shipping
            ->setPriceHt($commande['commande_port_ht'])
            ->setTaxCode('FR020100');
        // https://taxcode.avatax.avalara.com/
        return $shipping;
    }
}
