<?php

namespace Bydedi\Avalara\Adapter;

use Bydedi\Avalara\Model\Address;
use Bydedi\Avalara\Model\Customer;
use Bydedi\Avalara\Model\Product;
use Bydedi\Avalara\Model\Shipping;
use Panier;

/**
 * Class PanierAdapter
 * @package Bydedi\Avalara\Adapter
 */
class PanierAdapter
{
    /**
     * @var Panier
     */
    protected $panier;

    /**
     * PanierAdapter constructor.
     * @param Panier $panier
     */
    public function __construct(Panier $panier)
    {
        $this->panier = $panier;
    }

    /**
     * ////////////////////////////////////
     * GETTERS & SETTERS
     * ////////////////////////////////////
     */

    /**
     * @return Panier
     */
    public function getPanier()
    {
        return $this->panier;
    }

    /**
     * @param $panier
     * @return $this
     */
    public function setPanier(Panier $panier)
    {
        $this->panier = $panier;
        return $this;
    }

    /**
     * ////////////////////////////////////
     * PUBLIC METHODS
     * ////////////////////////////////////
     */

    /**
     * @return Customer
     */
    public function getCustomer()
    {
        $customer = new Customer();
        $customer->code = $this->panier->getCustomer()->client_id;

        return $customer;
    }

    /**
     * @return Address
     */
    public function getAddressShipping(){
        $panier = $this->getPanier();
        $addressShipping = $panier->getAddressShipping();

        $address = new Address();
        $address
            ->setLine1($addressShipping->__get('adresse_rue'))
            ->setLine2($addressShipping->__get('adresse_rue2'))
            ->setCity($addressShipping->__get('adresse_ville'))
            ->setCountry($addressShipping->__get('pays_iso_code_2'))
            ->setPostalCode($addressShipping->__get('adresse_cp'));

        if(!empty($addressShipping->__get('catalog_state_us_code'))){
                $address->setRegion($addressShipping->__get('catalog_state_us_code'));
        }

        return $address;
    }

    /**
     * @return array
     */
    public function getProducts()
    {
        $result = array();
        foreach($this->getPanier()->getProducts() as $p){
            $product = new Product();
            $product
                ->setIdentifier($p['identifier'])
                ->setPriceHt($p['produit_prix_ht'])
                ->setQuantity((float)$p['quantite_order'])
                ->setTaxCode('P0000000');
            // TODO : TaxCode susceptible de changer
            $result[] = $product;
        }
        return $result;
    }

    /**
     * @return Shipping
     */
    public function getShipping(){
        $shipping = new Shipping();
        $shipping
            ->setPriceHt($this->getPanier()->getShipping()->__get('port_ht'))
            ->setTaxCode('FR020100');
        return $shipping;
    }
}
