<?php

namespace Bydedi\Avalara\Adapter;

use Bydedi\Avalara\Model\Address;
use Bydedi\Avalara\Model\Customer;
use Bydedi\Avalara\Model\Product;
use Bydedi\Avalara\Model\Shipping;

/**
 * Class PanierAdapter
 * @package Bydedi\Avalara\Adapter
 */
class PanierSessionAdapter
{
    /**
     * @var array
     */
    protected $panier;

    /**
     * PanierAdapter constructor.
     * @param array $panier
     */
    public function __construct(array $panier)
    {
        $this->panier = $panier;
    }

    /**
     * ////////////////////////////////////
     * GETTERS & SETTERS
     * ////////////////////////////////////
     */

    /**
     * @return array
     */
    public function getPanier()
    {
        return $this->panier;
    }

    /**
     * @param $panier
     * @return $this
     */
    public function setPanier(array $panier)
    {
        $this->panier = $panier;
        return $this;
    }

    /**
     * ////////////////////////////////////
     * PUBLIC METHODS
     * ////////////////////////////////////
     */

    /**
     * @return Customer
     */
    public function getCustomer()
    {
        $customer = new Customer();
        $customer->code = $_SESSION['client_id'];

        return $customer;
    }

    /**
     * @return Address
     */
    public function getAddressShipping(){

        if(empty($_SESSION['commande']['livraison'])) {
            $address = new Address();
            return $address;
        }
        $address = new Address();
        $address
            ->setLine1($_SESSION['commande']['livraison']['adresse_rue'])
            ->setLine2($_SESSION['commande']['livraison']['adresse_rue2'])
            ->setCity($_SESSION['commande']['livraison']['adresse_ville'])
            ->setCountry($_SESSION['commande']['livraison']['pays_iso_code_2'])
            ->setPostalCode($_SESSION['commande']['livraison']['adresse_cp'])
            ->setCountry($_SESSION['commande']['livraison']['pays_code'])
        ;

        if(!empty($_SESSION['commande']['livraison']['catalog_state_us_code'])){
                $address->setRegion($_SESSION['commande']['livraison']['catalog_state_us_code']);
        }

        return $address;
    }

    /**
     * @return array
     */
    public function getProducts()
    {
        $result = array();
        foreach($this->getPanier() as $p){
            $product = new Product();
            $code = 'P0000000';
            if(!empty($p['produit_code_avalara'])) {
                $code = $p['produit_code_avalara'];
            }
            $product
                ->setIdentifier($p['produit_id'])
                ->setPriceHt($p['produit_prix_ht'])
                ->setQuantity((float)$p['produit_quantite'])
                ->setTaxCode($code);
            $result[] = $product;
        }
        return $result;
    }

    /**
     * @return Shipping
     */
    public function getShipping(){
        $shipping = new Shipping();

        $port = 0;
        if(!empty($_SESSION['commande']['port']['port_ht'])) {
            $port= $_SESSION['commande']['port']['port_ht'];
        }
        $shipping
            ->setPriceHt($port)
            ->setTaxCode('FR020100');
        return $shipping;
    }
}
